#include <algorithm>
#include <queue>
#include <stdio.h>
#include <vector>

/* Node and distance */
struct NodeAndDist {
  int u;
  int dist;

  bool operator<(const NodeAndDist& c) const {
    return dist > c.dist;
  }
};


int main() {
  int n, m;
  scanf("%d%d", &n, &m);

  // Adjacency list representation of the graph.
  std::vector<std::vector<NodeAndDist>> adj(n, std::vector<NodeAndDist>());
  std::priority_queue<NodeAndDist> pq;

  for (int i = 0; i < m; ++i) {
    int a, b, c;
    scanf("%d%d%d", &a, &b, &c);
    --a; --b; // Make the nodes zero based.
    adj[a].push_back({ b, c });
    adj[b].push_back({ a, c });
  }
  
  /* Main code for Prim's algorithm. */
  std::vector<bool> visited(n, false);
  long long total_cost = 0;
  pq.push({ 0, 0 });
  while (!pq.empty()) {
    auto top_candidate = pq.top();
    pq.pop();

    if (!visited[top_candidate.u]) {
      visited[top_candidate.u] = true;
      total_cost += top_candidate.dist;

      for (auto neigh : adj[top_candidate.u]) {
        pq.push({ neigh.u, neigh.dist });
      }
    }
  }
  printf("%lld\n", total_cost);

  return 0;
}
